@@ -14,8 +14,8 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-HTTPS_ONLY = 'EGGPLANT_HTTPS_ONLY'
-DEPLOYED = 'EGGPLANT_DEPLOYED'
+HTTPS_ONLY = 'HTTPS_ONLY'
+DEPLOYED = 'DEPLOYED'
 
 PERMISSION_DICT = 'EGGPLANT_PERMISSION_DICT'
 
